import { BehaviorSubject, Observable } from 'rxjs';
import { DkColumnMesh } from './dk-column-mesh';
import { DkColumnMeshSlot, DkGutterMeshSlot, DkMeshSlot } from './dk-column-mesh-slot';
import { DkGridPanel } from '../panels/dk-grid-panels';
import { DkColumnDef, DkDataColumnDef } from './dk-column-def';
import { DkSlotPlacement } from '../common/dk-slot-placement';
import { DropConnectedElements } from '../common/dk-draggable-containers';
import { DkFilter, DkFilterable } from '../filtering/dk-filter.model';
import { DkConfig } from '../grid/dk-config';
import { DkGridConfig } from '../grid/dk-grid-config.service';
import { DkGridFactoryColumns } from './dk-grid-factory-columns.service';
import { DkGridFactoryMeshSlots } from './dk-grid-factory-mesh-slots.service';
import { DkGridFilterConfig } from '../filtering/dk-grid-filter-config.service';
import { DkSortDispatcher } from '../sorting/dk-sort-dispatcher.service';
import { DkGridEditionConfig } from '../editing/dk-grid-edition-config.service';
import { CustomFilterConditionInstance } from '../filtering/dk-filter-factory.service';
export declare abstract class DkColumnStructure<T extends object, P extends DkGridPanel> {
    panel: P;
    protected dikeConfig: DkConfig;
    protected gridConfig: DkGridConfig;
    protected gridFactoryColumns: DkGridFactoryColumns<T>;
    protected gridFactoryMeshSlots: DkGridFactoryMeshSlots<T>;
    protected gridFilterConfig: DkGridFilterConfig<T>;
    protected sortDispatcher: DkSortDispatcher<T>;
    protected gridEditionConfig: DkGridEditionConfig<T>;
    protected measureScrollLeftOffset: number;
    protected gridColumnMesh: DkColumnMesh;
    protected scrollbarGapSlot: DkColumnMeshSlot;
    protected listHeightSubject: BehaviorSubject<number>;
    protected scrollbarGapSlotSubject: BehaviorSubject<DkColumnMeshSlot>;
    protected horizontalGutterSlotSubject: BehaviorSubject<DkSlotPlacement>;
    protected outerColumnSlotsSubject: BehaviorSubject<DkColumnMeshSlot[]>;
    protected colSlotsSubject: BehaviorSubject<DkColumnMeshSlot[]>;
    protected dataColumnSlotsSubject: BehaviorSubject<DkColumnMeshSlot[]>;
    protected containerWidthSubject: BehaviorSubject<number>;
    protected columnSetVisibilitySubject: BehaviorSubject<boolean>;
    /**
     * gutterSlotOverSubject and gutterSlotResizingSubject are used to notify:
     *
     *    (a).  that some column is being dragging over the sent gutter slot, or
     *    (b).  Which gutter slot is being resizing.
     *
     * The horizontal gutter is the only consumer of these Behavior Subjects to
     * splitting its horizontal line.
     */
    protected gutterSlotOverSubject: BehaviorSubject<DkGutterMeshSlot>;
    protected gutterSlotResizingSubject: BehaviorSubject<DkGutterMeshSlot>;
    protected panelResizingSubject: BehaviorSubject<boolean>;
    private columnResizedSubject;
    constructor(panel: P, dikeConfig: DkConfig, gridConfig: DkGridConfig, gridFactoryColumns: DkGridFactoryColumns<T>, gridFactoryMeshSlots: DkGridFactoryMeshSlots<T>, gridFilterConfig: DkGridFilterConfig<T>, sortDispatcher: DkSortDispatcher<T>, gridEditionConfig: DkGridEditionConfig<T>);
    get onListHeightChanged$(): Observable<number>;
    get onOuterColumnSlotsChanged$(): Observable<DkColumnMeshSlot[]>;
    get onColumnSlotsChanged$(): Observable<DkColumnMeshSlot[]>;
    get onDataColumnSlotsChanged$(): Observable<DkColumnMeshSlot[]>;
    get onScrollbarGapSlotChanged$(): Observable<DkColumnMeshSlot>;
    get onContainerWidthChanged$(): Observable<number>;
    get onColumnSetVisibilityChanged$(): Observable<boolean>;
    get onHorizontalGutterSlotChanged$(): Observable<DkSlotPlacement>;
    get onGutterSlotOverChanged$(): Observable<DkGutterMeshSlot>;
    get onGutterSlotResizingChanged$(): Observable<DkGutterMeshSlot>;
    get onPanelResizingChanged$(): Observable<boolean>;
    get onColumnSizeChanged$(): Observable<DkDataColumnDef<T, string | number | Date | boolean | null | undefined>>;
    get firstColumnSlot(): DkColumnMeshSlot;
    get lastColumnSlot(): DkColumnMeshSlot;
    setGreatestHeight(value: number): void;
    setScrollbarGapColumnSlot(visible: boolean, width?: number): void;
    getColumnSlots(): DkColumnMeshSlot[];
    getDataColumnSlots(): DkColumnMeshSlot[];
    getAllDataColumnSlots(): DkColumnMeshSlot[];
    getAllRootColumnSlots(): DkColumnMeshSlot[];
    getColumnSlot(columnId: string): DkColumnMeshSlot;
    getColumnSlotByUniqueId(slotId: string): DkColumnMeshSlot;
    getSlot(columnId: string): DkMeshSlot;
    getSlotByUniqueId(slotId: string): DkMeshSlot;
    getDataColumnSlotsFromSlot(columnId: string): DkColumnMeshSlot[];
    doesSlotExist(slotId: string): boolean;
    /**
     * Panel-tree structure method.
     *
     * Parameter belongToGroupId represents the group id which some slot belongs to. The given group id is
     * looked for in the entire panel tree structure.
     *
     * It uses getDikeColumnMeshListInstance method from DkColumnMesh abstract class. If the corresponding
     * double-linked list instance exists then the group exists.
     *
     * @param {string} belongToGroupId The group id which is looked for.
     *
     * @returns {boolean} Returns true if the group exists in the current panel.
     */
    doesGroupExist(belongToGroupId: string): boolean;
    getColumnSlotWidth(columnId: string): number;
    setColumnSlotWidth(columnSlot: DkColumnMeshSlot, value: number): void;
    setColumnSlotsOrder(index: number): void;
    isColumnStructureVisible(): boolean;
    isPanelResizing(value: boolean): void;
    getMeasureScrollLeftOffset(): number;
    setMeasureScrollLeftOffset(value: number): void;
    getListDropppableIdsByBelongToGroupSlot(belongToGroupId: string): DropConnectedElements;
    notifySlotOver(slot: DkMeshSlot, value: boolean): void;
    notifySlotResizing(gutterSlot: DkGutterMeshSlot, value: boolean): void;
    /**
     * Instance level-list method.
     *
     * Given the column slot, all its children are returned in a DkColumnDef structure
     * including the column slot itself.
     *
     * If lineOfAscent flag is true, then all the column slots above the given column slot
     * are retrieved.
     *
     * The column slots above the given column slot are its parent and the parent of its
     * parent and so forth.
     *
     * @param {DkColumnMeshSlot} columnSlot The column slot which will be cloned.
     * @param {boolean} lineOfAscent Flag which indicates if the line of ascent of the given column slot is retrieved or not. Default value is false.
     *
     * @returns {DkColumnDef} The cloned column slot stored in a DkColumnDef instance.
     */
    cloneColumnSlot(columnSlot: DkColumnMeshSlot, lineOfAscent: boolean): DkColumnDef;
    /**
     * Instance level-list method.
     *
     * The given column slot is removed from the corresponding level-list instance.
     *
     * This method remove sortable and filterables from the corresponding map variables.
     *
     * @param {DkColumnMeshSlot} columnSlot The column slot which will be deleted.
     *
     * @returns {DkColumnDef} Returns the deleted column slot as a cloned DkColumnDef.
     */
    removeColumnSlot(columnSlot: DkColumnMeshSlot): DkColumnDef;
    /**
     * Instance level-list method.
     *
     * The given column slot is removed from the corresponding level-list instance but its
     * sortables and filterables are not removed, if the given column slot has them.
     *
     * The DikeGrid instance is cloning column slots due to swapping columns between panels.
     *
     * The difference between removeColumnSlot(...) method with this method, is that if the
     * given columnSlot has sortables and filterables, they do not be removed from its
     * map variables. Therefore, the given column slot must be cloned before. When the
     * cloned columnDef is inserted into the destination panel:
     *
     *  1. Its sortable is updated as active if the DikeGrid was sorted with the given
     *     column slot. Finally, the older sortable is removed from the map variables.
     *
     *  2. Its filterables (context filterable and row filterable) are set from the older
     *     filterables taken from the map variable. Finally, older filterables are removed
     *     from the map variable.
     *
     * IMPORTANT: When filterables are cloned, they are cloned silently meaning not sending
     *            register and deregister events, avoiding proccesing the existing filters
     *            because they have already been applied before.
     *
     * @param {DkColumnMeshSlot} columnSlot The column slot which will be deleted.
     * @param {boolean} notifyChanges A flag that indicates if the Observables must be updated. Its default value is true.
     *
     * @returns {DkColumnDef} Returns the deleted column slot as a cloned DkColumnDef.
     */
    removeClonedColumnSlot(columnSlot: DkColumnMeshSlot, notifyChanges?: boolean): DkColumnDef;
    setColumnSlotFilterability(columnSlot: DkColumnMeshSlot, isFilterable: boolean, filter?: DkFilter[], customFilterConditions?: CustomFilterConditionInstance<T>): void;
    removeAllFilterables(onlyRowFilterables?: boolean): void;
    /**
     * Instance level-list method.
     *
     * Source and destination slots will be interchage between them.
     *
     * Source and destination slots must live in the same instance list.
     *
     * @param {DkColumnMeshSlot} sourceColumnSlot The source, data or group, column.
     * @param {DkColumnMeshSlot} destinationColumnSlot The destination, data or group, column.
     *
     * @returns {void} No return value.
     */
    swapColumnSlots(sourceColumnSlot: DkColumnMeshSlot, destinationColumnSlot: DkColumnMeshSlot): void;
    /**
     * Instance level-list method.
     *
     * Source slot will be place before or after the destination gutter slot.
     *
     * Source slot will be place before the gutter slot, if the slot lives in the right panel. Otherwise,
     * the source slot will be place after the destination gutter slot.
     *
     * Source and destination slots must live in the same instance list.
     *
     * @param {DkColumnMeshSlot} sourceColumnSlot The source, data or group, column.
     * @param {DkMeshSlot} destinationSlot The destination gutter.
     *
     * @returns {void} No return value.
     */
    swapColumnSlotToGutterSlot(sourceColumnSlot: DkColumnMeshSlot, destinationSlot: DkMeshSlot): void;
    /**
     * Instance level-list method.
     *
     * External column will be place before or after the destination gutter slot. External column must
     * live in a different panel of the destination gutter slot.
     *
     * If external column is a Group column and the same group exists in the
     * destination panel, then it will be joined to its group. After the joining operation,
     * the group is moved before or after the destination gutter slot.
     *
     * If external column is a data column, the data column is moved before or after the destination gutter slot.
     *
     * External column will be place before the gutter slot, if the slot lives in the right panel. Otherwise,
     * the external solumn will be place after the destination gutter slot.
     *
     * @param {DkColumnDef} externalColumnDef The external column which will be place before or after the destination gutter slot.
     * @param {DkMeshSlot} destinationSlot The destination gutter slot.
     *
     * @returns {boolean} True if the movement was done successfully.
     */
    insertExternalColumnSlotToGutter(externalColumnDef: DkColumnDef, destinationSlot: DkMeshSlot): boolean;
    /**
     * Instance level-list method.
     *
     * External column will be place at the destination column slot. External column must
     * live in a different panel of the destination column slot.
     *
     * If external column is a Group column and the same group exists in the
     * destination panel, then it will be joined to its group. Otherwise, the external
     * column slot will be place at the place occupied by destination column slot.
     *
     * Destination column slot will be removed from the destination panel.
     *
     * @param {DkColumnDef} externalColumnDef The external column which will be added to the destination panel.
     * @param {DkColumnMeshSlot} destinationColumnSlot The destination column slot which will be removed of the destination panel in
     * order to give its place.
     *
     * @returns {boolean} True if the movement was done successfully.
     */
    insertExternalColumnDefAtDestinationColumnSlot(externalColumnDef: DkColumnDef, destinationColumnSlot: DkColumnMeshSlot): boolean;
    /**
     * Panel-tree structure method.
     *
     * It receives a group or data column that will be inserted into the panel list. If the column is a group
     * column, the method is called recursively until it reaches the leaves (data columns).
     *
     * The given column is inserted into the given DkColumnMesh instance level-list represented by currentLevelList
     * parameter.
     *
     * The method adds the column filterability if the column has a filter specified.
     *
     * Finally, the method is used for internal purposes. Therefore, is used to insert cloned columns as well.
     *
     * @param {DkGroupColumnDef | DkDataColumnDef} columnDef The group or data column to be inserted into the panel list.
     * @param {DkColumnMesh} currentLevelList An instance of type DkColumnMesh that corresponds to the given group represented by belongToGroup.
     * @param {string} belongToGroup The group id which the given column belongs to.
     *
     * @returns {DkColumnMeshSlot} The just inserted slot.
     */
    protected addColumnIntoList(columnDef: DkColumnDef, currentLevelList: DkColumnMesh, belongToGroup: string): DkColumnMeshSlot;
    /**
     * Panel-tree structure method.
     *
     * The method only accepts cloned columns.
     *
     * It is called recursively finding all the group and data columns that do not exist
     * in the destination panel inserting them into its corresponding level-list instance.
     *
     * @param {DkGroupColumnDef | DkDataColumnDef} columnDef The group or data column to be inserted into the panel list.
     *
     * @returns {void} No return value.
     */
    protected joinGroupColumnIntoList(columnDef: DkColumnDef, startingList: DkColumnMesh): void;
    protected clearFilterablesAndSortablesFromRemovedColumnSlot(columnDef: DkColumnDef): void;
    protected addFilterable(filterable: DkFilterable<T>): void;
    protected removeFilterable(columnId: string): void;
    protected changeListHeight(value: number): void;
    protected changeOuterColumnSlots(): void;
    protected changeColSlots(): void;
    protected changeScrollbarGapSlot(value: DkColumnMeshSlot): void;
    protected changeGutterSlotOver(value: DkGutterMeshSlot): void;
    protected changeGutterSlotResized(value: DkGutterMeshSlot): void;
    protected changePanelResized(value: boolean): void;
    protected emitColumnResizing(columnSlot: DkColumnMeshSlot): void;
    abstract addColumn(columnDef: DkColumnDef): void | DkColumnMeshSlot;
    abstract addColumnsFromPanel(columns: DkColumnDef[]): void;
    abstract cloneColumnSlotForMoving(columnSlot: DkColumnMeshSlot, destinationPanel: DkColumnStructure<T, P>): DkColumnDef;
    protected abstract createChildrenList(panel: P, belongToGroupId: string): DkColumnMesh;
    protected abstract getOuterSlots(): DkColumnMeshSlot[];
    protected abstract changeGridTemplateColumns(): void;
}
