import { TemplateRef } from '@angular/core';
import { BehaviorSubject, Observable } from 'rxjs';
import { DkColumnMeshSlot } from './dk-column-mesh-slot';
import { DkContentPanel, DkGridPanel } from '../panels/dk-grid-panels';
import { DkColumnDef, DkGroupColumnDef, DisplayStatus } from './dk-column-def';
import { EditionFieldSettings } from '../editing/dk-edition.model';
import { DkColumnStructure } from './dk-column-structure';
import { DkColumnMesh } from './dk-column-mesh';
import { DkConfig } from '../grid/dk-config';
import { DkFilter } from '../filtering/dk-filter.model';
import { DkGridConfig } from '../grid/dk-grid-config.service';
import { DkGridFactoryMeshSlots } from './dk-grid-factory-mesh-slots.service';
import { DkGridFactoryColumns } from './dk-grid-factory-columns.service';
import { DkGridFilterConfig } from '../filtering/dk-grid-filter-config.service';
import { DkSortDispatcher } from '../sorting/dk-sort-dispatcher.service';
import { DkGridEditionConfig } from '../editing/dk-grid-edition-config.service';
export declare class DkContentColumnStructure<T extends object> extends DkColumnStructure<T, DkContentPanel> {
    protected dataSourceIndexSlot: DkColumnMeshSlot;
    protected dataSourceIndexSlotSubject: BehaviorSubject<DkColumnMeshSlot>;
    protected gridTemplateColumnsContentSubject: BehaviorSubject<string>;
    protected gridTemplateColumnsHeaderSubject: BehaviorSubject<string>;
    private columnGroupStatusSubject;
    private columnLockedSubject;
    private columnUnLockedSubject;
    private columnVisibleSubject;
    private changeClearFilterSubscription;
    private changeEditionStateSubscription;
    constructor(panel: DkContentPanel, dikeConfig: DkConfig, gridConfig: DkGridConfig, gridFactoryColumns: DkGridFactoryColumns<T>, gridFactoryMeshSlots: DkGridFactoryMeshSlots<T>, gridFilterConfig: DkGridFilterConfig<T>, sortDispatcher: DkSortDispatcher<T>, gridEditionConfig: DkGridEditionConfig<T>);
    destroy(): void;
    get onDataSourceIndexSlotChanged$(): Observable<DkColumnMeshSlot>;
    get onGridTemplateColumnsContentChanged$(): Observable<string>;
    get onGridTemplateColumnsHeaderChanged$(): Observable<string>;
    get onColumnGroupStatusChanged$(): Observable<DkGroupColumnDef>;
    get onColumnLockedChanged$(): Observable<DkColumnDef>;
    get onColumnUnLockedChanged$(): Observable<DkColumnDef>;
    get onColumnVisibleChanged$(): Observable<DkColumnDef>;
    setRowIndexColumnSlot(visible: boolean, width?: number): void;
    /**
     * Panel-tree structure method.
     *
     * This method is used for inserting new columns or cloned ones.
     * To differentiate a cloned column its slotId and its belongToGroup fields will not be null.
     *
     * If the given DkColumnDef is a cloned column, then the joinColumnGroup(...) method is called.
     * Otherwise, the column is treat as a new column and addColumnIntoList(...) method is called instead.
     *
     * @param {string} columnDef The column which will be inserted in the panel tree.
     *
     * @returns {void} No return value.
     */
    addColumn(columnDef: DkColumnDef): void;
    addColumnsFromPanel(columns: DkColumnDef[]): void;
    cloneColumnSlotForMoving(columnSlot: DkColumnMeshSlot, destinationPanel: DkColumnStructure<T, DkGridPanel>): DkColumnDef;
    setColumnSlotVisible(columnSlot: DkColumnMeshSlot, isVisible: boolean): void;
    setColumnSlotEditable(columnSlot: DkColumnMeshSlot, isEditable: boolean, settings?: {
        editionSettings?: EditionFieldSettings;
        editionTemplate?: TemplateRef<any>;
    }): void;
    setColumnSlotGroupable(columnSlot: DkColumnMeshSlot, isGroupable: boolean): void;
    setDefaultEditionTemplateColumnSlot(columnSlot: DkColumnMeshSlot): void;
    setDisplayTemplateColumnSlot(columnSlot: DkColumnMeshSlot, displayTemplate: TemplateRef<any>): void;
    setDefaultDisplayTemplateColumnSlot(columnSlot: DkColumnMeshSlot): void;
    setColumnSlotDraggable(columnSlot: DkColumnMeshSlot, isDraggable: boolean): void;
    setColumnSlotLocking(columnSlot: DkColumnMeshSlot, isLocked: boolean): void;
    setColumnSlotResizable(columnSlot: DkColumnMeshSlot, isResizable: boolean): void;
    changeColumnSlotWidth(columnSlot: DkColumnMeshSlot, columnSize: {
        width: number;
        minWidth?: number;
        maxWidth?: number;
    }): void;
    setDisplayStatusToColumnSlotGroup(columnId: string, displayStatus: DisplayStatus): void;
    setColumnSlotSortable(columnSlot: DkColumnMeshSlot, isSortable: boolean): void;
    changeColumnSlotFilter(columnSlot: DkColumnMeshSlot, newFilter: DkFilter[]): void;
    protected createChildrenList(panel: DkContentPanel, belongToGroupId: string): DkColumnMesh;
    protected getOuterSlots(): DkColumnMeshSlot[];
    protected changeGridTemplateColumns(): void;
    protected emitColumnGroupStatusChanging(columnSlot: DkColumnMeshSlot): void;
    protected emitColumnLocking(columnSlot: DkColumnMeshSlot): void;
    protected emitColumnUnLocking(columnSlot: DkColumnMeshSlot): void;
    protected emitColumnVisible(columnSlot: DkColumnMeshSlot): void;
    private changeDataSourceIndexSlot;
    private setChangeEditionStateSubscription;
    private setChangeClearFilterSubscription;
}
