import { OnDestroy, TemplateRef } from '@angular/core';
import { Observable } from 'rxjs';
import { DkGridPanel } from '../panels/dk-grid-panels';
import { DkColumnDef, DkNodeColumnDef, DkDataColumnDef, DkGroupColumnDef, DisplayStatus, DkColumnMoveEvent } from './dk-column-def';
import { DkFilter } from '../filtering/dk-filter.model';
import { EditionFieldSettings } from '../editing/dk-edition.model';
import { DkGridFactoryColumns } from './dk-grid-factory-columns.service';
import { DkContentPanelDispatcher } from '../content/dk-content-panel-dispatcher.service';
import { CustomFilterConditionInstance } from '../filtering/dk-filter-factory.service';
import { DkGridPanelDispatcher } from '../panels/dk-grid-panel-dispatcher.service';
import * as i0 from "@angular/core";
export declare type CompareColumnFn = (column: DkColumnDef) => boolean;
export declare type CompareNodeFn = (node: DkNodeColumnDef) => boolean;
export declare class DkGridColumnDef<T extends object> implements OnDestroy {
    private gridFactoryColumns;
    private gridPanelDispatcher;
    private contentPanelDispatcher;
    private columnDefSubject;
    private changeColumnDefSubscription;
    constructor(gridFactoryColumns: DkGridFactoryColumns<T>, gridPanelDispatcher: DkGridPanelDispatcher<T>, contentPanelDispatcher: DkContentPanelDispatcher<T>);
    get columnSizeChange(): Observable<DkDataColumnDef<T, string | number | Date | boolean | null | undefined>>;
    get columnGroupStatusChange(): Observable<DkGroupColumnDef>;
    get columnLockedChange(): Observable<DkColumnDef>;
    get columnUnLockedChange(): Observable<DkColumnDef>;
    get columnVisibleChange(): Observable<DkColumnDef>;
    get columnMove(): Observable<DkColumnMoveEvent>;
    get columnsChange(): Observable<DkColumnDef[]>;
    get contentPanelsColumnsChange(): Observable<DkColumnDef[]>;
    get columnsRemovedChange(): Observable<DkColumnDef[]>;
    ngOnDestroy(): void;
    addColumns(columns: DkColumnDef | DkColumnDef[]): void;
    removeColumns(columns: DkColumnDef | DkColumnDef[]): void;
    findColumn(compare: CompareColumnFn): DkColumnDef;
    findNode(compare: CompareNodeFn): DkNodeColumnDef;
    swapColumns(sourceColumn: DkColumnDef, destinationColumn: DkColumnDef): void;
    movePanelColumns(fromPanel: DkGridPanel, destinationPanel: DkGridPanel, onlyVisibleColumns?: boolean): void;
    moveColumnIntoPanel(column: DkColumnDef, panel: DkGridPanel): void;
    moveColumnAfter(column: DkColumnDef, targetColumn: DkColumnDef): void;
    moveColumnBefore(column: DkColumnDef, targetColumn: DkColumnDef): void;
    getColumns(): DkColumnDef[];
    getLinkedColumns(columns: DkColumnDef[]): DkNodeColumnDef[];
    setColumnVisible(column: DkColumnDef, isVisible: boolean): void;
    setColumnEditable<R extends string | number | Date | boolean | null | undefined>(column: DkDataColumnDef<T, R>, isEditable: boolean, settings?: {
        editionSettings?: EditionFieldSettings;
        editionTemplate?: TemplateRef<any>;
    }): void;
    setDefaultEditionTemplateColumn<R extends string | number | Date | boolean | null | undefined>(column: DkDataColumnDef<T, R>): void;
    setDisplayTemplateColumn<R extends string | number | Date | boolean | null | undefined>(column: DkDataColumnDef<T, R>, displayTemplate: TemplateRef<any>): void;
    setDefaultDisplayTemplateColumn<R extends string | number | Date | boolean | null | undefined>(column: DkDataColumnDef<T, R>): void;
    lockColumn(column: DkColumnDef): void;
    unlockColumn(column: DkColumnDef): void;
    setColumnResizable(column: DkColumnDef, isResizable: boolean): void;
    changeColumnWidth<R extends string | number | Date | boolean | null | undefined>(column: DkDataColumnDef<T, R>, columnSize: {
        width: number;
        minWidth?: number;
        maxWidth?: number;
    }): void;
    setColumnGroupable(column: DkDataColumnDef<T, string | number | Date | boolean | null | undefined>, isGroupable: boolean): void;
    setColumnFilterability<R extends string | number | Date | boolean | null | undefined>(column: DkDataColumnDef<T, R>, isFilterable: boolean, filter?: DkFilter[], customFilterConditions?: CustomFilterConditionInstance<T>): void;
    changeColumnFilter<R extends string | number | Date | boolean | null | undefined>(column: DkDataColumnDef<T, R>, filter: DkFilter[]): void;
    displayRowIndexColumn(visible: boolean, width?: number): void;
    changeColumnGroupStatus(columnGroup: DkGroupColumnDef, status: DisplayStatus): void;
    setColumnSortable<R extends string | number | Date | boolean | null | undefined>(column: DkDataColumnDef<T, R>, isSortable: boolean): void;
    private cloneColumns;
    private orderColumns;
    private createLinkedDikeColumnDefStructure;
    private searchColumnInArray;
    private searchNodeInTree;
    private setChangeColumnDefSubscription;
    static ɵfac: i0.ɵɵFactoryDeclaration<DkGridColumnDef<any>, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DkGridColumnDef<any>>;
}
