export interface INode<T> {
    value: T;
    prev?: INode<T>;
    next?: INode<T>;
    children?: DoubleLinkedList<T>;
    selfList: DoubleLinkedList<T>;
    selfHeight: number;
}
export declare type TFunction<T, R> = (t: T) => R;
export declare abstract class DoubleLinkedList<T> {
    protected treeLevel: number;
    protected listHeight: number;
    protected maxHeight: number;
    protected parentNode: INode<T>;
    protected headNode: INode<T>;
    protected tailNode: INode<T>;
    constructor();
    get first(): INode<T>;
    get last(): INode<T>;
    get level(): number;
    set level(value: number);
    get height(): number;
    set height(value: number);
    get greatestHeight(): number;
    set greatestHeight(value: number);
    get parent(): INode<T>;
    set parent(value: INode<T>);
    isEmpty: () => boolean;
    toArray(): T[];
    getAllLeavesArray(): T[];
    protected append(value: T, children: DoubleLinkedList<T>): INode<T>;
    protected prepend(value: T, children: DoubleLinkedList<T>): INode<T>;
    protected removeNode(node: INode<T>): INode<T>;
    protected insertNodeBefore(node: INode<T>, before: INode<T>): void;
    protected insertNodeAfter(node: INode<T>, after: INode<T>): void;
    protected insertNodeAt(newNode: INode<T>, nodeAt: INode<T>): INode<T>;
    protected swapNodes(source: INode<T>, destination: INode<T>): boolean;
    items(): Generator<INode<T>, void, unknown>;
    find(compare: TFunction<T, boolean>): INode<T>;
    findInTree(compare: TFunction<T, boolean>): INode<T>;
    printList(out: any): void;
    abstract insert(value: T, children: DoubleLinkedList<T>): void;
    protected createNode(value: T, children: DoubleLinkedList<T>): INode<T>;
    protected areNodesContiguous(source: INode<T>, destination: INode<T>): {
        contiguous: boolean;
        leftDestination: boolean;
        rightDestination: boolean;
    };
}
