import { OnDestroy, TemplateRef, EventEmitter } from '@angular/core';
import { Observable } from 'rxjs';
import { DkColumnMeshSlot, DkMeshSlot } from '../columns/dk-column-mesh-slot';
import { DkColumnStructure } from '../columns/dk-column-structure';
import { DkContentColumnStructure } from '../columns/dk-content-column-structure';
import { DkContentPanel, DkGridPanel, PanelsVisibilityTruthTable } from '../panels/dk-grid-panels';
import { DkColumnDef, DkGroupColumnDef, DisplayStatus } from '../columns/dk-column-def';
import { DkFilter } from '../filtering/dk-filter.model';
import { EditionFieldSettings } from '../editing/dk-edition.model';
import { DkConfig } from '../grid/dk-config';
import { DkPanelDispatcher } from '../panels/dk-panel-dispatcher.service';
import { DkGridConfig } from '../grid/dk-grid-config.service';
import { CustomFilterConditionInstance } from '../filtering/dk-filter-factory.service';
import { DkGridFactoryMeshSlots } from '../columns/dk-grid-factory-mesh-slots.service';
import { DkGridFactoryColumns } from '../columns/dk-grid-factory-columns.service';
import { DkGridFilterConfig } from '../filtering/dk-grid-filter-config.service';
import { DkSortDispatcher } from '../sorting/dk-sort-dispatcher.service';
import { DkGridEditionConfig } from '../editing/dk-grid-edition-config.service';
import { DkGridSelectionConfig } from '../selection/dk-grid-selection-config.service';
import { DkGeneralNotifier } from '../common/dk-general-notifier.service';
import { DkRowGroupingConfig } from '../row-grouping/dk-row-grouping-config.service';
import { DkRowGroupingDispatcher } from '../row-grouping/dk-row-grouping-dispatcher.service';
import * as i0 from "@angular/core";
export declare class DkContentPanelDispatcher<T extends object> extends DkPanelDispatcher<T, DkContentPanel> implements OnDestroy {
    private gridSelectionConfig;
    private generalNotifier;
    private rowGroupingConfig;
    private rowGroupingDispatcher;
    readonly columnGroupStatusEmitter: EventEmitter<DkGroupColumnDef>;
    readonly columnLockedEmitter: EventEmitter<DkColumnDef>;
    readonly columnUnLockedEmitter: EventEmitter<DkColumnDef>;
    readonly columnVisibleEmitter: EventEmitter<DkColumnDef>;
    private isDataSourceIndexVisible;
    private dataSourceIndexWidth;
    private listHeightSubject;
    private gridTemplateHeaderColumnPanelsSubject;
    private gridTemplateContentColumnPanelsSubject;
    private panelsVisibilitySubject;
    private currentScrollingPanelSubject;
    private moveHorizontalScrollingSubject;
    private dikeConfig;
    private gridConfig;
    private gridEditionConfig;
    private changesContainerWidthSubscription;
    private changesPanelsVisibilitySubscription;
    private emitColumnGroupStatusSubscription;
    private emitColumnLockedSubscription;
    private emitColumnUnLockedSubscription;
    private emitColumnVisibleSubscription;
    constructor(dikeConfig: DkConfig, gridConfig: DkGridConfig, gridFactoryColumns: DkGridFactoryColumns<T>, gridFactoryMeshSlots: DkGridFactoryMeshSlots<T>, gridFilterConfig: DkGridFilterConfig<T>, sortDispatcher: DkSortDispatcher<T>, gridEditionConfig: DkGridEditionConfig<T>, gridSelectionConfig: DkGridSelectionConfig<T>, generalNotifier: DkGeneralNotifier, rowGroupingConfig: DkRowGroupingConfig, rowGroupingDispatcher: DkRowGroupingDispatcher<T>);
    ngOnDestroy(): void;
    get onListHeightChanged$(): Observable<number>;
    get onGridTemplateHeaderColumnPanelsChanged$(): Observable<string>;
    get onGridTemplateContentColumnPanelsChanged$(): Observable<string>;
    get onPanelsVisibilityChanged$(): Observable<PanelsVisibilityTruthTable>;
    get onCurrentScrollingPanelChanged$(): Observable<DkContentPanel | null>;
    get onMoveHorizontalScrollingChanged$(): Observable<number>;
    get contentPanels(): Partial<Record<DkContentPanel, DkColumnStructure<T, DkContentPanel>>>;
    get leftPanel(): DkContentColumnStructure<T>;
    get centerPanel(): DkContentColumnStructure<T>;
    get rightPanel(): DkContentColumnStructure<T>;
    /**
     * The method could receive one column or an array of columns of type DkColumnDef.
     *
     * This method will be used to insert new columns specified by the client user.
     * The columns could be specified inside the DikeGrid template component through
     * DikeGridColumn component via Content projection. Also, the user could instantiate
     * an object or an array of objects of type DkColumnDef directly.
     *
     * IMPORTANT NOTE: This method receive only root columns.
     *
     * @param {DkColumnDef | DkColumnDef[]} columns The column or columns to be added.
     *
     * @returns {void} No return value.
     */
    addColumns(columns: DkColumnDef | DkColumnDef[]): void;
    movePanelColumnSlots(fromPanel: DkColumnStructure<T, DkGridPanel>, destinationPanel: DkContentColumnStructure<T>, onlyVisibleColumnSlots: boolean): DkColumnDef[];
    moveColumnSlotIntoPanel(columnSlot: DkColumnMeshSlot, fromPanel: DkColumnStructure<T, DkGridPanel>, destinationPanel: DkContentColumnStructure<T>): DkColumnDef[];
    moveColumnSlotToGutterSlotInDifferentPanel(sourcePanel: DkColumnStructure<T, DkGridPanel>, sourceSlot: DkColumnMeshSlot, destinationPanel: DkContentColumnStructure<T>, destinationSlot: DkMeshSlot): void;
    joinColumnGroupSlots(sourcePanel: DkColumnStructure<T, DkGridPanel>, sourceSlot: DkColumnMeshSlot, destinationPanel: DkContentColumnStructure<T>, destinationSlot: DkColumnMeshSlot): void;
    swapColumnSlotsInDifferentPanel(sourcePanel: DkContentColumnStructure<T>, sourceSlot: DkColumnMeshSlot, destinationPanel: DkContentColumnStructure<T>, destinationSlot: DkColumnMeshSlot): void;
    changeColumnSlotFilter(columnSlot: DkColumnMeshSlot, newFilter: DkFilter[]): void;
    /**
     * To set or unset a filter to a column.
     *
     * @param {DkDataColumnDef} column The column to which a filter will be added or removed.
     * @param {boolean} isFilterable The flag that indicates if the filter will be added or removed.
     * @param {DkFilter} filter Optional parameter. The filter which will be applied to the column.
     * @param {CustomFilterConditionInstance} customFilterConditions Optional parameter. The conditions defined by the user that will apply only to this column.
     *
     * @returns {void} No return value.
     */
    setColumnSlotFilterability(columnSlot: DkColumnMeshSlot, isFilterable: boolean, filter?: DkFilter[], customFilterConditions?: CustomFilterConditionInstance<T>): void;
    /**
     * Change the column visibility.
     *
     * If the column has children, all of them get the column's visibility state.
     *
     * If the column has a parent column, then the parent must change its visibility
     * state depending on its child columns. This verification is done via the
     * verifyColumnVisibility() method from DkColumnMesh class.
     *
     * @param {DkColumnDef} column The column to which a visibility is applied.
     * @param {boolean} isVisible The flag that indicates if the column is visible or not.
     *
     * @returns {void} No return value.
     */
    setColumnSlotVisible(columnSlot: DkColumnMeshSlot, isVisible: boolean): void;
    setColumnSlotEditable(columnSlot: DkColumnMeshSlot, isEditable: boolean, settings?: {
        editionSettings?: EditionFieldSettings;
        editionTemplate?: TemplateRef<any>;
    }): void;
    setDefaultEditionTemplateColumnSlot(columnSlot: DkColumnMeshSlot): void;
    setDisplayTemplateColumnSlot(columnSlot: DkColumnMeshSlot, displayTemplate: TemplateRef<any>): void;
    setDefaultDisplayTemplateColumnSlot(columnSlot: DkColumnMeshSlot): void;
    setColumnSlotLocking(columnSlot: DkColumnMeshSlot, isLocked: boolean): void;
    setColumnSlotResizable(columnSlot: DkColumnMeshSlot, isResizable: boolean): void;
    changeColumnSlotWidth(columnSlot: DkColumnMeshSlot, columnSize: {
        width: number;
        minWidth?: number;
        maxWidth?: number;
    }): void;
    changeColumnSlotGroupStatus(columnGroupSlot: DkColumnMeshSlot, status: DisplayStatus): void;
    setColumnSlotGroupable(columnSlot: DkColumnMeshSlot, isGroupable: boolean): void;
    setColumnSlotSortable(columnSlot: DkColumnMeshSlot, isSortable: boolean): void;
    /**
     * To show or hide the index datasource column.
     *
     * panelsVisibilityTable parameter is used to establish which panel the index source column will have. The index column
     * will be set in the most-left visible panel.
     *
     * If the PanelsVisibilityTruthTable is not provides it will be calculated with the last visible state of
     * each panel.
     *
     * @param {boolean} visible The flag that indicates if the index column will be show or hide.
     * @param {number} width The width the column will have.
     * @param {PanelsVisibilityTruthTable} panelsVisibilityTable Optional parameter. The visibility state of the three panels.
     *
     * @returns {void} No return value.
     */
    setRowIndexColumnSlot(visible: boolean, width?: number, panelsVisibilityTable?: PanelsVisibilityTruthTable): void;
    isLeftPanelScrollGap(panelsTable: PanelsVisibilityTruthTable): boolean;
    isCenterPanelScrollGap(panelsTable: PanelsVisibilityTruthTable): boolean;
    isRightPanelScrollGap(panelsTable: PanelsVisibilityTruthTable): boolean;
    moveHorizontalScroll(units: number): void;
    getMeasureScrollLeftOffset(panel: DkContentPanel): number;
    setMeasureScrollLeftOffset(panel: DkContentPanel, value: number): void;
    getCurrentHorizontalScrollingPanel(): DkContentPanel | null;
    getPanelsVisibilityTruthTable(): PanelsVisibilityTruthTable;
    private setOuterSlots;
    private getContentContainerGridTemplateColumns;
    private calculatePanelsVisibilityTruthTable;
    private changeCurrentHorizontalScrollingPanel;
    protected setChangeListHeightSubscription(): void;
    private setChangePanelsVisibilitySubscription;
    private setChangeContainerWidthSubscription;
    protected setChangeDataColumnSlotsSubscription(): void;
    protected setChangeColumnSlotsSubscription(): void;
    protected setChangeShareableDropElementsSubscription(): void;
    private setEmitColumnGroupStatusSubscription;
    private setEmitColumnLockedSubscription;
    private setEmitColumnVisibleSubscription;
    private setEmitColumnUnLockedSubscription;
    static ɵfac: i0.ɵɵFactoryDeclaration<DkContentPanelDispatcher<any>, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DkContentPanelDispatcher<any>>;
}
