import { EventEmitter, OnDestroy } from '@angular/core';
import { Observable } from 'rxjs';
import type { DkGridComponent } from '../grid/dk-grid/dk-grid.component';
import { DkGridDataRowEntry, DkGridRowEntry } from '../rows/dk-grid-row-entry';
import { DkDataSource, DkGridDataSource, DkGridDataSourceInput } from './dk-datasource';
import { DkRowGroupingDispatcher } from '../row-grouping/dk-row-grouping-dispatcher.service';
import { DkGeneralNotifier } from '../common/dk-general-notifier.service';
import { DkGridSelectionConfig } from '../selection/dk-grid-selection-config.service';
import { DkGridSelection } from '../selection/dk-grid-selection.service';
import { DkGridEditionConfig } from '../editing/dk-grid-edition-config.service';
import { DkRowGroupingConfig } from '../row-grouping/dk-row-grouping-config.service';
import { DkPaginationDispatcher } from '../paging/dk-pagination-dispatcher.service';
import { DkGridFilterConfig } from '../filtering/dk-grid-filter-config.service';
import { DkFilterDispatcher } from '../filtering/dk-filter-dispatcher.service';
import { DkGridMessaging } from '../grid/dk-grid-messaging.service';
import * as i0 from "@angular/core";
export declare type DataSourceDecoratorFn<T extends object> = (dikeDataSource: DkDataSource<DkGridDataRowEntry<T>>, dikeGrid: DkGridComponent<T>) => DkDataSource<DkGridDataRowEntry<T>>;
export declare type DataSourceDecoratorCtxFn<T extends object> = () => (dikeDataSource: DkDataSource<DkGridDataRowEntry<T>>) => DkDataSource<DkGridDataRowEntry<T>>;
export declare class DkDataSourceDispatcher<T extends object> implements OnDestroy {
    private gridSelection;
    private gridSelectionConfig;
    private gridEditionConfig;
    private rowGroupingConfig;
    private rowGroupingDispatcher;
    private paginationDispatcher;
    private gridFilterConfig;
    private filterDispatcher;
    private generalNotifier;
    private gridMessaging;
    readonly dataDeliveryEmitter: EventEmitter<string>;
    private dataDeliveryId;
    private isCustomDataSourceType;
    private gridDataSourceSubject;
    private contentDataSourceSubject;
    private decoratorFnSubject;
    private tempDisableSortPaginationSubject;
    private changeDataDeliverySubscription;
    private changeObservableDataSourceSubscription;
    private changeContentDataSourceSubscription;
    private changeRootGroupRowSubscription;
    private changeEditionFilterStateSubscription;
    constructor(gridSelection: DkGridSelection<T>, gridSelectionConfig: DkGridSelectionConfig<T>, gridEditionConfig: DkGridEditionConfig<T>, rowGroupingConfig: DkRowGroupingConfig, rowGroupingDispatcher: DkRowGroupingDispatcher<T>, paginationDispatcher: DkPaginationDispatcher, gridFilterConfig: DkGridFilterConfig<T>, filterDispatcher: DkFilterDispatcher<T>, generalNotifier: DkGeneralNotifier, gridMessaging: DkGridMessaging);
    ngOnDestroy(): void;
    get onDikeGridDataSourceChanged$(): Observable<DkGridDataSource<T> | null>;
    get onContentDataSourceChanged$(): Observable<DkDataSource<DkGridRowEntry> | null>;
    get onDecoratorFnChanged$(): Observable<DataSourceDecoratorCtxFn<T> | null>;
    get onTempDisableSortPaginationChanged$(): Observable<boolean>;
    get gridDataSource(): DkGridDataSource<T> | null;
    get decoratorCtxFn(): DataSourceDecoratorCtxFn<T>;
    set decoratorCtxFn(value: DataSourceDecoratorCtxFn<T>);
    attachDikeGridDataSource(value: DkGridDataSourceInput<T>, dikeGrid: DkGridComponent<T>): void;
    getDefaultDataSourceDecorators(dikeDataSource: DkDataSource<DkGridDataRowEntry<T>>, dikeGrid: DkGridComponent<T>): DkDataSource<DkGridDataRowEntry<T>>;
    isCustomDataSource(datasource: DkGridDataSourceInput<T>): boolean;
    createEditionFilteringDecorator(gridDataSource: DkGridDataSource<T>): DkDataSource<DkGridDataRowEntry<T>>;
    private createRefreshingDecorator;
    private createPagedDataSource;
    private setChangeObservableDataSourceSubscription;
    private setChangeDataDeliverySubscription;
    private setChangeRootGroupRowSubscription;
    private setChangeEditionFilterStateSubscription;
    private changeDikeGridDataSource;
    private changeDikeGridContentDataSource;
    private changeDecoratorFn;
    static ɵfac: i0.ɵɵFactoryDeclaration<DkDataSourceDispatcher<any>, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DkDataSourceDispatcher<any>>;
}
