import { DataSource } from '@angular/cdk/collections';
import { Observable } from 'rxjs';
import { DkGridDataRowEntry } from '../rows/dk-grid-row-entry';
export declare type DkGridDataSourceInput<T extends object> = DataSource<T> | DkDataSource<T> | DkGridDataSource<T> | Observable<ReadonlyArray<T> | T[]> | ReadonlyArray<T> | T[];
export declare abstract class DkDataSource<T> extends DataSource<T> {
    constructor();
    abstract get data(): T[];
    abstract set data(value: T[]);
    abstract connect(): Observable<T[]>;
    abstract disconnect(): void;
    abstract reconnect(): void;
    abstract dispose(releaseSource: boolean): void;
}
export declare class DkGridDataSource<T extends object> extends DkDataSource<DkGridDataRowEntry<T>> {
    private rowsSubject;
    private dataDeliverySubject;
    constructor();
    get dataDeliveryChanges(): Observable<string>;
    get data(): DkGridDataRowEntry<T>[];
    set data(value: DkGridDataRowEntry<T>[]);
    get entries(): ReadonlyArray<T>;
    set entries(value: ReadonlyArray<T>);
    connect(): Observable<DkGridDataRowEntry<T>[]>;
    /**
     * It does not matter how many times we disconnect the decorators,
     * the base data stream continue alive.
     *
     * disconnect() method is defined empty for two reasons:
     *
     *  1.  Every time a new datasource is bound to the CdkVirtualFor directive, the
     *      cdkVirtualFor disconnect the previuos datasource.
     *
     *  2.  Before creating a new set of decorators the previous decorators
     *      must be removed and a new decorated instance is created. Remember that
     *      changing decorators is a very common task.
     *
     * Due to the previous reasons, if releasing-resources logic would have been left in the disconnect
     * method, in the first changing-decorators operation the base data stream (the rowsSubject subject)
     * would be completed.
     */
    disconnect(): void;
    reconnect(): void;
    dispose(releaseSource: boolean): void;
    private changeRows;
    private changeDataDelivery;
}
