import { EventEmitter, OnDestroy } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { Observable } from 'rxjs';
import { DkColumnMeshSlot } from '../columns/dk-column-mesh-slot';
import { DkContentPanel } from '../panels/dk-grid-panels';
import { DkGridDataRowEntry } from '../rows/dk-grid-row-entry';
import { DkContentPanelDispatcher } from '../content/dk-content-panel-dispatcher.service';
import { DkGridCommandFactory } from './dk-grid-command-factory.service';
import { DkGridDataStore } from '../datasource/dk-grid-data-store.service';
import { DkGridSelection } from '../selection/dk-grid-selection.service';
import { DkGridEditionConfig } from './dk-grid-edition-config.service';
import { DkGridColumnDef } from '../columns/dk-grid-column-def.service';
import { DkGridConfig } from '../grid/dk-grid-config.service';
import { DkGridMessaging } from '../grid/dk-grid-messaging.service';
import * as i0 from "@angular/core";
export declare class DkGridRowEditionDispatcher<T extends object> implements OnDestroy {
    private gridConfig;
    private contentPanelDispatcher;
    private gridCommandFactory;
    private gridSelection;
    private gridDataStore;
    private gridEditionConfig;
    private gridColumnDef;
    private gridMessaging;
    rowsInEdition: UntypedFormGroup;
    private history;
    private cardinalityHistory;
    private rowsInEditionSubject;
    readonly editionRowEmitter: EventEmitter<DkGridDataRowEntry<T>>;
    readonly updateRowEmitter: EventEmitter<DkGridDataRowEntry<T> | DkGridDataRowEntry<T>[]>;
    readonly cancelRowEditionEmitter: EventEmitter<DkGridDataRowEntry<T> | DkGridDataRowEntry<T>[]>;
    readonly deleteRowEmitter: EventEmitter<DkGridDataRowEntry<T> | DkGridDataRowEntry<T>[]>;
    readonly undoRowUpdateEmitter: EventEmitter<DkGridDataRowEntry<T> | DkGridDataRowEntry<T>[]>;
    constructor(gridConfig: DkGridConfig, contentPanelDispatcher: DkContentPanelDispatcher<T>, gridCommandFactory: DkGridCommandFactory<T>, gridSelection: DkGridSelection<T>, gridDataStore: DkGridDataStore<T>, gridEditionConfig: DkGridEditionConfig<T>, gridColumnDef: DkGridColumnDef<T>, gridMessaging: DkGridMessaging);
    ngOnDestroy(): void;
    get onRowsInEditionChanged$(): Observable<void>;
    initialized(): Observable<void>;
    cardinalityRowHistory(rowId: number): Observable<number>;
    createRowFormGroup(row: DkGridDataRowEntry<T>, panel: DkContentPanel, dataSlots: DkColumnMeshSlot[]): void;
    markRowAsPristine(row: DkGridDataRowEntry<T>): void;
    markGridEditionAsPristine(): void;
    areGridRowsInEditionPristine(): boolean;
    editRow(row: DkGridDataRowEntry<T>): void;
    updateRow(row: DkGridDataRowEntry<T>): void;
    cancelRowEdition(row: DkGridDataRowEntry<T>, sendEvent?: boolean): void;
    undoRowUpdate(row: DkGridDataRowEntry<T>): void;
    deleteRow(row: DkGridDataRowEntry<T>): void;
    saveEdition(): void;
    deleteRows(givenRows: DkGridDataRowEntry<T>[]): void;
    cancelEdition(): void;
    undoRows(givenRows: DkGridDataRowEntry<T>[]): void;
    canEditMoreRows(): boolean;
    getRowsInEdition(): DkGridDataRowEntry<T>[];
    getUpdatedRows(): DkGridDataRowEntry<T>[];
    getDeletedRows(): DkGridDataRowEntry<T>[];
    areThereRowsInEdition(): boolean;
    areThereRowsModified(): boolean;
    areThereRowsRemoved(): boolean;
    clearHistory(): void;
    releaseEdition(): void;
    private getUpdateAction;
    private getDeleteAction;
    private getLastMemento;
    private doesRowHaveMementos;
    private saveCurrentRowState;
    private getFieldUpdateArray;
    private changeRowFormGroupReference;
    private markAncestorsAsDirty;
    private markAncestorsAsTouched;
    private getComplementPanels;
    private getValidators;
    private getAsyncValidators;
    private getUpdateOnValue;
    private deleteSubsetOfValidRows;
    private restoreSubsetOfValidRows;
    private getCardinalityRowHistorySubject;
    private changeCardinalityRowHistory;
    private changeRowsInEditionSet;
    private changeEditionRow;
    private changeSaveRow;
    private changeCancelRowEdition;
    private changeDeleteRowEdition;
    private changeUndoRowUpdate;
    static ɵfac: i0.ɵɵFactoryDeclaration<DkGridRowEditionDispatcher<any>, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DkGridRowEditionDispatcher<any>>;
}
