import { EventEmitter } from '@angular/core';
import { DkColumnDataType } from '../columns/dk-column-def';
import { CustomFilterConditionInstance } from './dk-filter-factory.service';
import { LogicalOperator } from './dk-filter-types';
export interface DkFilterable<T extends object> {
    columnId: string;
    dataType: DkColumnDataType;
    fieldName: string;
    headerText: string;
    caseSensitive?: boolean;
    filter?: DkFilter[];
    customFilterConditions?: CustomFilterConditionInstance<T>;
}
export interface DkFilter {
    logicalOperator: LogicalOperator;
    condition: string;
}
export interface DkTextFilter extends DkFilter {
    value?: string;
}
export interface DkTextCaseFilter extends DkTextFilter {
    caseSensitive: boolean;
}
export interface DkNumericFilter extends DkFilter {
    value1?: number;
    value2?: number;
}
export interface DkDateFilter extends DkFilter {
    value1?: Date;
    value2?: Date;
}
export interface DkBinaryFilter extends DkFilter {
    value?: string;
}
export interface DkFilterBehaviour<T = any> {
    filterChange: EventEmitter<T>;
    isFilterApplied: () => boolean;
    addCondition: () => void;
    clear: () => void;
    applyFilter: () => void;
}
/**
 * Filter component's emissions:
 *
 * DkTextFilterComponent emits DkTextFilterEmission
 * DkNumericFilterComponent emits DkNumericFilterEmission
 * DkDateFilterComponent emits DkDateFilterEmission
 * DkBinaryFilterComponent emits DkBinaryFilterEmission
 */
export interface DkTextFilterEmission {
    caseSensitive: boolean;
    filter: DkTextFilter[];
}
export interface DkNumericFilterEmission {
    filter: DkNumericFilter[];
}
export interface DkDateFilterEmission {
    filter: DkDateFilter[];
}
export interface DkBinaryFilterEmission {
    filter: DkBinaryFilter[];
}
export declare type DkFilterEmission = DkTextFilterEmission | DkNumericFilterEmission | DkDateFilterEmission | DkBinaryFilterEmission;
